@@ -16,7 +16,7 @@ $reflector->reflect_schema(
   ],
 );
 
-__PACKAGE__->meta->make_immutable;1;
+__PACKAGE__->meta->make_immutable;
 
 1;
 
