@@ -16,24 +16,28 @@ use aliased 'Reaction::UI::ViewPort::Field::Container';
 
 use aliased 'Reaction::InterfaceModel::Object' => 'IM_Object';
 
+use MooseX::Types::Moose qw/ArrayRef HashRef/;
+
 use namespace::clean -except => [ qw(meta) ];
 extends 'Reaction::UI::ViewPort';
 
+with 'Reaction::UI::ViewPort::Role::Actions';
+
 #everything is read only right now. Later I can make somethings read-write
 #but first I need to figure out what depends on what so we can have decent triggers
 has model  => (is => 'ro', isa => IM_Object, required => 1);
-has fields => (is => 'ro', isa => 'ArrayRef', lazy_build => 1);
+has fields => (is => 'ro', isa => ArrayRef, lazy_build => 1);
 
 has field_args    => (is => 'rw');
-has field_order   => (is => 'ro', isa => 'ArrayRef');
+has field_order   => (is => 'ro', isa => ArrayRef);
 
-has builder_cache   => (is => 'ro', isa => 'HashRef',  lazy_build => 1);
-has excluded_fields => (is => 'ro', isa => 'ArrayRef', lazy_build => 1);
-has included_fields => (is => 'ro', isa => 'ArrayRef', lazy_build => 1);
-has computed_field_order => (is => 'ro', isa => 'ArrayRef', lazy_build => 1);
+has builder_cache   => (is => 'ro', isa => HashRef,  lazy_build => 1);
+has excluded_fields => (is => 'ro', isa => ArrayRef, lazy_build => 1);
+has included_fields => (is => 'ro', isa => ArrayRef, lazy_build => 1);
+has computed_field_order => (is => 'ro', isa => ArrayRef, lazy_build => 1);
 
-has containers => ( is => 'ro', isa => 'ArrayRef', lazy_build => 1);
-has container_layouts => ( is => 'rw', isa => 'ArrayRef' );
+has containers => ( is => 'ro', isa => ArrayRef, lazy_build => 1);
+has container_layouts => ( is => 'rw', isa => ArrayRef );
 
 sub BUILD {
   my ($self, $args) = @_;
